<?php

function stbl_get_recommend_entry( $attributes ) {

	if ( ! isset( $attributes['postId'] ) || empty( $attributes['postId'] ) ) return '';

	$post_id = $attributes['postId'];

	if ( get_post_status( $post_id ) !== 'publish' ) return '';

    /**
     * 日付
     */
	$date_type = 'post-update';

    if ( isset( $attributes['dateType'] ) && ! empty( $attributes['dateType'] ) ) {
        $date_type = $attributes['dateType'];
    }

	/**
     * 抜粋
     */
    $has_excerpt = false;
    $excerpt_length = 60;
    
    if ( isset( $attributes['hasExcerpt'] ) && ! empty( $attributes['hasExcerpt'] ) ) {
        $has_excerpt = $attributes['hasExcerpt'];
    }

    if ( isset( $attributes['excerptLength'] ) && ! empty( $attributes['excerptLength'] ) ) {
        $excerpt_length = $attributes['excerptLength'];
        $excerpt_length = intval( $excerpt_length );
    }

	$excerpt = '';

	if ($has_excerpt) {
		$excerpt = stbl_get_post_excerpt( $post_id, $excerpt_length );
	}

    /**
     * カテゴリー
     */
    $has_cat = false;
    $cat_design = 'left-top';
    if ( isset( $attributes['hasCategory'] ) && ! empty( $attributes['hasCategory'] ) ) {
        $has_cat = $attributes['hasCategory'];
    }

    if ( isset( $attributes['categoryDesign'] ) && ! empty( $attributes['categoryDesign'] ) ) {
        $cat_design = $attributes['categoryDesign'];
    }

	/**
	 * タイトル
	 */
	$title = get_the_title( $post_id );
	$title = stbl_mb_substr_text( $title, 100 );
	$title = esc_attr( $title );

	$thumb_data = stbl_get_thumbnail_info( $post_id, "large" );

	$has_thumb = $thumb_data && isset( $thumb_data[0] ) && $thumb_data[0];

    ob_start();
?>
    <div class="stbl-entries-item">
		<a href="<?php echo get_the_permalink( $post_id ); ?>" class="stbl-entries-item__inner">
			<figure class="stbl-entries-item__thumb">
				<?php if ( $has_thumb ): ?>
					<img src="<?php echo $thumb_data[0]; ?>" width="<?php echo $thumb_data[1]; ?>" height="<?php echo $thumb_data[2]; ?>" alt="<?php echo $title; ?>" loading="lazy" />
				<?php endif; ?>
			</figure>
			<div class="stbl-entries-item__content">
				<?php stbl_get_post_date_tag( $post_id, $date_type ); ?>
				<p class="stbl-entries-item__ttl">
					<?php echo $title; ?>
				</p>
				<?php if ( $has_excerpt ) : ?>
					<p class="stbl-entries-item__excerpt">
						<?php echo $excerpt; ?>
					</p>
				<?php endif; ?>
				<?php if ( $has_cat ) : ?>
					<?php stbl_entry_category( $post_id, $cat_design ); ?>
				<?php endif; ?>
			</div>
		</a>
	</div>
<?php
    $content = ob_get_clean();

    return $content;
}

function stbl_register_block_recommend_entry() {
	register_block_type('streetist-blocks/recommend-entry', array(
		'editor_script' => 'editor-script-streetist-blocks',
		'editor_style' => 'editor-style-streetist-blocks',
		'script' => 'script-streetist-blocks',
		'style' => 'style-streetist-blocks',
		'attributes' 	=> array(
			'postId' => array(
				'type' => 'string',
				'default' => '',
			),
            'dateType' => array(
				'type' => 'string',
                'default' => 'post-update'
            ),
			'hasExcerpt' => array(
                'type' => 'boolean',
                'default' => false,
            ),
            'excerptLength' => array(
                'type' => 'number',
                'default' => '60',
            ),
            'hasCategory' => array(
                'type' => 'boolean',
                'default' => false,
            ),
            'categoryDesign' => array(
                'type' => 'string',
                'default' => 'left-top',
            ),
		),
		'render_callback'	=> 'stbl_get_recommend_entry',
	));
}
add_action('init', 'stbl_register_block_recommend_entry');